====================
st-LLM Search Engine
====================


.. image:: https://img.shields.io/pypi/v/st_llm_search_engine.svg
        :target: https://pypi.python.org/pypi/st_llm_search_engine

.. image:: https://img.shields.io/travis/chips-fries/st_llm_search_engine.svg
        :target: https://travis-ci.com/chips-fries/st_llm_search_engine

.. image:: https://readthedocs.org/projects/st-llm-search-engine/badge/?version=latest
        :target: https://st-llm-search-engine.readthedocs.io/en/latest/?version=latest
        :alt: Documentation Status




A Streamlit component enabling LLM-driven semantic search and data retrieval.


* Free software: MIT license
* Documentation: https://st-llm-search-engine.readthedocs.io.


Features
--------

* TODO

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
